// Copyright © Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.opengroup.osdu.notification.provider.azure.di;

import org.opengroup.osdu.core.common.http.IHttpClient;
import org.opengroup.osdu.core.common.model.http.DpsHeaders;
import org.opengroup.osdu.core.common.notification.ISubscriptionFactory;
import org.opengroup.osdu.core.common.notification.ISubscriptionService;
import org.opengroup.osdu.core.common.notification.SubscriptionAPIConfig;
import org.opengroup.osdu.core.common.notification.SubscriptionService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Primary;
import org.springframework.stereotype.Component;

import java.util.Objects;

@Component
@Primary
public class SubscriptionFactoryAzure implements ISubscriptionFactory {

    private final SubscriptionAPIConfig config;
    private final IHttpClient client;

    @Autowired
    public SubscriptionFactoryAzure(final SubscriptionAPIConfig subscriptionConfig, final IHttpClient httpClient) {
        Objects.requireNonNull(subscriptionConfig, "SubscriptionAPIConfig cannot be null");
        this.config = subscriptionConfig;
        this.client = httpClient;
    }

    @Override
    public ISubscriptionService create(final DpsHeaders dpsHeaders) {
        Objects.requireNonNull(dpsHeaders, "headers cannot be null");
        return new SubscriptionService(this.config, this.client, dpsHeaders);
    }
}
