// Copyright © Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.opengroup.osdu.notification.di;

import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.mockito.InjectMocks;
import org.opengroup.osdu.core.common.util.IServiceAccountJwtClient;
import org.opengroup.osdu.notification.provider.azure.di.ServiceAccountJwtClientFactory;
import org.opengroup.osdu.notification.provider.azure.util.ServiceAccountJwtAzureClientImpl;

import static org.junit.Assert.fail;
import static org.mockito.MockitoAnnotations.initMocks;

public class ServiceAccountJwtClientFactoryTest {

    @InjectMocks
    ServiceAccountJwtClientFactory sut;

    @Before
    public void init() {
        initMocks(this);
    }

    @Test
    public void testGettingInstance() {
        try {
            // Act
            Class<?> objectType = sut.getObjectType();
            // Assert
            Assert.assertEquals(IServiceAccountJwtClient.class, objectType);

            // Act
            IServiceAccountJwtClient serviceAccountJwtClient = sut.createInstance();
            // Assert
            Assert.assertNotNull("Should not be null", serviceAccountJwtClient);
            Assert.assertEquals(serviceAccountJwtClient.getClass(), ServiceAccountJwtAzureClientImpl.class);
        } catch (Exception exception) {
            fail("Should not throw this exception" + exception.getMessage());
        }
    }

}