
// Copyright © Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.opengroup.osdu.notification.provider.azure;

import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;
import org.mockito.junit.MockitoJUnitRunner;
import org.opengroup.osdu.core.common.logging.JaxRsDpsLog;
import org.opengroup.osdu.core.common.model.http.AppException;
import org.opengroup.osdu.notification.provider.azure.pubsub.EventGridHandshakeHandler;
import org.opengroup.osdu.notification.provider.azure.pubsub.EventGridRequestBodyExtractor;
import org.springframework.http.HttpStatus;

import java.io.IOException;

import static org.junit.Assert.fail;
import static org.mockito.Mockito.when;

@RunWith(MockitoJUnitRunner.class)
public class EventGridHandshakeHandlerTest {
    @Mock
    private EventGridRequestBodyExtractor eventGridRequestBodyExtractor;

    @Mock
    private JaxRsDpsLog logger;

    @InjectMocks
    @Spy
    private EventGridHandshakeHandler sut;

    @Test
    public void should_returnValidResponse_getHandshakeResponse() {
        // Set up
        when(sut.getHandshakeResponse()).thenReturn("testValidationCode");
        String expectedResponse = "{\"ValidationResponse\":\"testValidationCode\"}";

        // Act
        String observedResponse = this.sut.getHandshakeResponse();

        // Assert
        Assert.assertEquals(observedResponse, expectedResponse);
    }

    @Test
    public void should_throw_getHandshakeResponse() {
        // Set up
        when(eventGridRequestBodyExtractor.getValidationCodeForHandshake())
                .thenThrow(new AppException(HttpStatus.BAD_REQUEST.value(), "Request payload parsing error", "" ));
        try{
            // Act
            String observedResponse = this.sut.getHandshakeResponse();

            // Assert
            fail("Should Throw Exception");
        } catch (AppException appException){
            Assert.assertEquals(HttpStatus.BAD_REQUEST.value(), appException.getError().getCode());
        } catch (Exception exception) {
            fail("Should Throw AppException");
        }
    }
}
