// Copyright © Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.opengroup.osdu.notification.util;

import com.azure.security.keyvault.secrets.SecretClient;
import com.azure.security.keyvault.secrets.models.KeyVaultSecret;
import org.junit.Before;
import org.junit.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.opengroup.osdu.notification.provider.azure.util.AppProperties;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertThrows;
import static org.mockito.Mockito.doReturn;
import static org.mockito.MockitoAnnotations.initMocks;

public class AppPropertiesTest {

    @InjectMocks
    private AppProperties sut;

    @Mock
    private SecretClient kv;

    @Mock
    private KeyVaultSecret secret;

    @Before
    public void init() {
        initMocks(this);
    }

    @Test
    public void should_throwWhenSecretNameIsNull_getKeyVaultSecret() {
        // Set-Up
        doReturn(null).when(kv).getSecret("app-dev-sp-password");

        // Act
        IllegalStateException exception = assertThrows(IllegalStateException.class, () -> sut.getAuthClientSecret());

        // Assert
        assertEquals("No secret found with name app-dev-sp-password", exception.getMessage());
    }

    @Test
    public void should_returnRightClientAuth_getCosmosKey() {
        // Set-Up
        doReturn("client-auth-secret").when(secret).getValue();
        doReturn(secret).when(kv).getSecret("app-dev-sp-password");

        // Act
        String secretValue = sut.getAuthClientSecret();

        // Assert
        assertEquals( "client-auth-secret", secretValue);
    }

    @Test
    public void should_returnRightCosmosSecret_getCosmosKey() {
        // Set-Up
        doReturn("cosmos-endpoint-secret").when(secret).getValue();
        doReturn(secret).when(kv).getSecret("app-dev-sp-username");

        // Act
        String secretValue = sut.getAuthClientID();

        // Assert
        assertEquals( "cosmos-endpoint-secret", secretValue);
    }

    @Test
    public void should_returnRightAuthURL_getCosmosKey() {
        // Set-Up
        doReturn("test").when(secret).getValue();
        doReturn(secret).when(kv).getSecret("app-dev-sp-tenant-id");

        // Act
        String secretValue = sut.getAuthURL();

        // Assert
        assertEquals( "https://login.microsoftonline.com/test/oauth2/token/", secretValue);
    }
}
